==> java-1.2.3.tar.gz: java-1.2.3/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/unit/security/ValidateCertificateTest.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Dejbjerg Pedersen, Lenio
 *   Hans Guldager Knudsen, Lenio
 *   Patrik Johansson, Accenture
 *   Dennis Sgaard, Accenture
 *   Martin Bentzen, Accenture
 *   Jesper Jensen, Avanade
 *   Ramzi Fadel, Avanade
 *   Christian Pedersen, Accenture
 *   Morten Hougesen, Accenture
 *   Mikkel Hippe Brun, ITST
 *   Finn Hartmann Jordal, ITST
 *   Christian Lanng, ITST
 *
 */

package dk.gov.oiosi.test.unit.security;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import junit.framework.TestCase;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.exception.MainException;
import dk.gov.oiosi.security.revocation.IRevocationLookup;
import dk.gov.oiosi.security.revocation.RevocationLookupFactory;
import dk.gov.oiosi.security.revocation.RevocationResponse;
import dk.gov.oiosi.security.revocation.RevocationException;
import dk.gov.oiosi.security.validation.CertificateExpiredException;
import dk.gov.oiosi.security.validation.CertificateNotActiveException;
import dk.gov.oiosi.security.validation.CertificateValidator;
import dk.gov.oiosi.test.integration.security.revocation.OcspRequestTest;
import dk.gov.oiosi.test.TestConstants;

public class ValidateCertificateTest extends TestCase {
    private Log log = LogFactory.getLog(OcspRequestTest.class);
    static {ConfigurationHandler.setConfigurationFile(TestConstants.PATH_TEST_RASPCONFIGURATION);}

    /**
     * Read certificate from keystore.
     */
    protected X509Certificate getCertificate(String keylabel) throws Exception {
        // define receiver certificate
        KeyStore ks = KeyStore.getInstance("JKS");
        ks.load(new FileInputStream(TestConstants.PATH_KEYSTORE_TEST), TestConstants.PASSWORD_KEYSTORE_TEST.toCharArray());

        X509Certificate client = (X509Certificate) ks.getCertificate(keylabel);
        return client;
    }

    /**
     * Test validating certificate.
     */
	private X509Certificate performQuery(String keylabel, boolean expectValid) {
        log.info("Check Certificate : " + keylabel);
        X509Certificate cert = null;
        try {
            KeyStore ks = KeyStore.getInstance("JKS");
            ks.load(new FileInputStream(TestConstants.PATH_KEYSTORE_TEST), TestConstants.PASSWORD_KEYSTORE_TEST.toCharArray());
            cert = (X509Certificate) ks.getCertificate(keylabel);
        } catch (Exception e) {
            fail("Could not read certificate from keystore : " + keylabel);
        }
        IRevocationLookup lookup = null;
        try {
            lookup = RevocationLookupFactory.createRevocationLookupClient();
        } catch (Exception e) {
            fail("Could not init OcspLookup");
        }
        try {
            log.info("Start check : " + cert.getSubjectDN());
            RevocationResponse response = lookup.checkCertificate(cert);
            if (response.isValid() && expectValid) {
            } else {
                log.info("Failed : Check Certificate should have failed: " + keylabel);
                fail("Failed : Check Certificate should have failed : " + keylabel);
            }
        } catch (RevocationException e) {
            if (expectValid) {
                log.info("Failed : Certificate expected to be validated : " + keylabel + " - Failure : " + e);
                fail("Failed : Certificate expected to be validated : " + keylabel + " - Failure : " + e);
            } else {
                log.info("Ok : Certificate failed to validated - as expected : " + keylabel);
                assertTrue("Ok : Certificate failed to validated - as expected : " + keylabel, true);
            }
        } catch (Throwable e) {
            fail("Ocsp Check Failed for : " + keylabel + " - Failure : " + e);
            e.printStackTrace();
        }
        return cert;
    }

	
	
	/**
	 *	test ocsp for expired certificate.
     */
    public void testExpired() {
        X509Certificate cert = performQuery("server_tdc_expired", true);
        assertTrue("We have certificate", cert != null);
        try {
        	CertificateValidator.validateCertificate(cert);
        } catch (CertificateNotActiveException e) {
        	fail("Expected expired, but was not yet active " + e);
        } catch (CertificateExpiredException e) {
        	// Success!
        	return;
        }
        fail("Expected expired, but was ok");
    }
    
    /**
     * Test ocsp for valid certificate.
     * @throws FileNotFoundException 
     * @throws CertificateException 
     */
    public void testValid() throws FileNotFoundException, CertificateException {
    	InputStream inStream = new FileInputStream(TestConstants.PATH_CERTIFICATE_VALID);
	    CertificateFactory cf = CertificateFactory.getInstance("X.509");	    
	    X509Certificate cert = (X509Certificate)cf.generateCertificate(inStream);
        try {
            assertTrue("We have certificate", cert != null);
            CertificateValidator.validateCertificate(cert);
        } catch (MainException e) {
            fail("Certicate should be valid " + e);
        } catch (Exception e) {
            fail("Unknow failure " + e);
        }
    }
    
}

==> java-2.0.0.tar.gz: java-2.0.0/dk.gov.oiosi.library/test/src/dk/gov/oiosi/test/unit/security/ValidateCertificateTest.java <==
/*
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this
 * file except in compliance with the License. You may obtain
 * a copy of the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 *
 * The Original Code is Java RASP toolkit.
 *
 * The Initial Developer of the Original Code is Lenio. Portions
 * created by Lenio are Copyright (C) 2007 Danish National IT and
 * Telecom Agency (http://www.itst.dk). All Rights Reserved.
 */

package dk.gov.oiosi.test.unit.security;

import dk.gov.oiosi.configuration.ConfigurationHandler;
import dk.gov.oiosi.security.validation.CertificateExpiredException;
import dk.gov.oiosi.security.validation.CertificateNotActiveException;
import dk.gov.oiosi.security.validation.CertificateValidator;
import dk.gov.oiosi.test.TestConstants;
import junit.framework.TestCase;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.security.KeyStore;
import java.security.cert.CertificateException;
import java.security.cert.CertificateFactory;
import java.security.cert.X509Certificate;

public class ValidateCertificateTest extends TestCase {

    @Override
    protected void setUp() throws Exception {
        super.setUp();

        ConfigurationHandler.setConfigurationFile(TestConstants.PATH_RASPCONFIGURATION_TEST);
    }

    // TODO: Add negative tests!

    /**
     * test ocsp for expired certificate.
     */
    public void testExpired() throws Exception {
        X509Certificate cert = getCertificate("server_tdc_expired");
        assertNotNull("Certificate not found", cert);
        try {
            CertificateValidator.validateCertificate(cert);
            fail("Expected expired, but was ok");
        } catch (CertificateNotActiveException e) {
            fail("Expected expired, but was not yet active " + e);
        } catch (CertificateExpiredException e) {
            // Success!
        }
    }

    /**
     * Test ocsp for valid certificate.
     *
     * @throws FileNotFoundException On error...
     * @throws CertificateException  On error...
     */
    public void testValid() throws Exception {
        InputStream inStream = new FileInputStream(TestConstants.PATH_FOCES1_VALID);
        CertificateFactory cf = CertificateFactory.getInstance("X.509");
        X509Certificate cert = (X509Certificate) cf.generateCertificate(inStream);
        assertNotNull("No certificate", cert);
        CertificateValidator.validateCertificate(cert);
    }

    /**
     * Read certificate from keystore.
     */
    protected X509Certificate getCertificate(String keyLabel) throws Exception {
        KeyStore ks = KeyStore.getInstance("JKS");
        ks.load(new FileInputStream(TestConstants.PATH_KEYSTORE_TEST), TestConstants.PASSWORD_KEYSTORE_TEST.toCharArray());

        return (X509Certificate) ks.getCertificate(keyLabel);
    }
}
